## Code for FSIS' 2024 Risk Assessments


#######################################
##### SET WORKING DIRECTORY       #####
#######################################

# Notes on files/etc

# Use 'setwd' to identify working directory where all files are saved
# e.g., setwd('Documents/FSIS_2024_Sal_Risk_Assessment_Model_Code/Chicken/Final_Product')


#######################################
##### LOAD LIBRARIES              #####
#######################################
library(truncnorm)
library(mc2d)

#######################################
##### SOURCE SUPPORTING FUNCTIONS #####
#######################################

#Begin EpiX

#SET WORKING DIRECTORY (setwd) TO ACCESS POLYNOMIAL2.CSV FILE
source("EpiX_To_Source_July_2024.R")  #EpiX Analytics dose-response code. Please see notes in code

#End EpiX

################################################################################
################################################################################
################################################################################



# Begin FSIS 

#########################################################################################
# Human cases of salmonellosis partitioned by chicken products                          #
#########################################################################################

FoodNet.cases =	7600  # per year
share.food =	0.66 #foodborne fraction (else is waterborne)
share.foreign =	0.11 # foreign travel associated illnesses 
FoodNet.coverage = 0.15 # FoodNet sites comprise 15% of U.S. population
UnderDx.mult =	24.3  # number of true cases for each reported case
Tot.salm.yr	= FoodNet.cases * share.food * (1-share.foreign) * UnderDx.mult/FoodNet.coverage
round(Tot.salm.yr)

chick.attrib =	0.173 #share of all illnesses attributed to chicken consumption
chick.ill <- chick.attrib * Tot.salm.yr
round(chick.ill)

carc.share = 0.11 #share of chicken illnesses from carcass consumption
ground.share =	0.06
parts.share =	0.83
carc.ill <- chick.ill * carc.share
ground.ill <- chick.ill * ground.share 
parts.ill <- chick.ill * parts.share
round(carc.ill)
round(ground.ill)
round(parts.ill)

###############################################################################
# MODEL INPUTS
# choose product to model ("carc"=carcasses, "parts"=parts, "comm"=comminuted)
###############################################################################

prod <- "carc"

# select number ill (Note: assume illnesses for carcass stand is total chicken illnesses)
num.ill <- ifelse(prod=="carc",chick.ill,ifelse(prod=="parts",parts.ill,ground.ill))

# total lots (production lots for carc, days of production for parts/comm)
tot.lots.carc <- 203718
tot.lots.parts<-104505 
tot.lots.comm <- 8545 
tot.lots <- ifelse(prod=="carc",tot.lots.carc,
            ifelse(prod=="parts",tot.lots.parts,tot.lots.comm))

# actual total samples collected per year
tot.sam.act.carc <- 9635  
tot.sam.act.parts <- 14192 
tot.sam.act.comm <- 1991 
tot.sam.act <- ifelse(prod=="carc",tot.sam.act.carc,
               ifelse(prod=="parts",tot.sam.act.parts,tot.sam.act.comm))

# fraction of tested-failed lots that will be diverted among all noncompliant lots 
alpha.compfrac <- tot.sam.act /tot.lots
alpha.compfrac  

# default fraction of salmonella in cluster 1
p.c1 <- 0.2 

# lognormal (log10) concentration parameters (represents between lot variability) 
mu.carc.ml=-4.51187
sig.carc=1.623983
mu.parts.ml=-3.017  
sig.parts=1.027     
mu.comm.g=-3.70 
sig.comm=1.949  

mu.init <- ifelse(prod=="carc",mu.carc.ml,ifelse(prod=="parts",mu.parts.ml,mu.comm.g)) 
sig.init <- ifelse(prod=="carc",sig.carc, ifelse(prod=="parts",sig.parts,sig.comm)) 

# attenuation distribution (adjusted for conversion from mL to g for carc and parts)
log.atten.mu <- -5+ifelse(prod=="comm",0,log10(400/0.14)+log10(1/(454*4)))
log.atten.sig <- 1.91

#######################################################################################
# BEGIN MODEL HERE
#######################################################################################

# calc exposure (dose) distribution as combination of init concentration and attenuation
log.dose.mu <- mu.init + log.atten.mu
log.dose.sig <- sqrt(sig.init^2+log.atten.sig^2)

# calculate prob of illness for each cluster across all exposures
p.ill.dose.C1 <- integrate(f,-Inf, Inf, mu=log.dose.mu, sigma=log.dose.sig, cluster=1, est="Mean")$value 
p.ill.dose.C2 <- integrate(f,-Inf, Inf, mu=log.dose.mu, sigma=log.dose.sig, cluster=2, est="Mean")$value

# calc a baseline probability of illness across all exposures
# need to weight by frequency of seroclusters 
p.ill.dose <- p.c1 * p.ill.dose.C1 + (1-p.c1) * p.ill.dose.C2
p.ill.dose.C1/p.ill.dose.C2


################### If serotype policy, then assume conc.thresh=1/30mL or 1/325grams ######################
#conc.thresh <- 1/30  # LOD for qualitative testing is 1/30mL or 1/325 g
###########################################################################################

# Prepare for simulation
conc.thresh=c(1/2600,1/1300,1/650,1/325,1/150,1/65,1/30,1/15,1/10,1/9,1/8,1/7,1/6,1/5,1/4,1/3,1/2,1,2,3,5,7.5,10,20,50,100)
num.conc=length(conc.thresh)

fail.pass=rep(0,num.conc)
passC1.C2=rep(0,num.conc)
failC1.C2=rep(0,num.conc)
p.ill.base=rep(0,num.conc)
p.ill.new=rep(0,num.conc)
p.ill.newer=rep(0,num.conc)
ill.avoid=rep(0,num.conc)
ill.avoid.newer=rep(0,num.conc)
ill.avoid.lot=rep(0,num.conc)
perc.red=rep(0,num.conc)
perc.red.newer=rep(0,num.conc)

for (k in 1:num.conc) {

# probability a lot fails threshold
p.lot.fail <- 1-pnorm(log10(conc.thresh[k]),mu.init,sig.init)
p.lot.fail 

# this is omega in our basic equation (fraction of lots that pass)
omega <- 1-p.lot.fail
omega

# number of tested lots that will fail
lots.fail <- tot.sam.act * p.lot.fail
round(lots.fail) 

# number of all lots that are non-compliant
lots.noncompliant <- tot.lots * p.lot.fail
round(lots.noncompliant)

#  Need probability of illness given passing and failing.
#  Because Dose-response functions depend on serocluster,
#  need to weight each p(ill | passing/failing) by serocluster 1 and 2 results.

# simulate p.ill for passing lots 
iter <- 1000000 #at least 100 million iterations are needed for stable results
pass.init <- 10^rtruncnorm(iter,a=-Inf,b=log10(conc.thresh[k]),mu.init,sig.init)
atten <- 10^rnorm(iter,log.atten.mu,log.atten.sig)
dose.pass <- pass.init*atten
Response.dose.pass <- DRPoly(dose.pass)
p.ill.dose.pass.C1 <- as.numeric(colMeans(Response.dose.pass)[1])
p.ill.dose.pass.C2 <- as.numeric(colMeans(Response.dose.pass)[4])

# calculate p.ill for failing lots
p.ill.dose.fail.C1 <- (p.ill.dose.C1 - omega*p.ill.dose.pass.C1)/(1-omega)
p.ill.dose.fail.C2 <- (p.ill.dose.C2 - omega*p.ill.dose.pass.C2)/(1-omega)

# combine results for passing and failing lots
p.ill.dose.pass <- p.c1 * p.ill.dose.pass.C1 + 
                  (1-p.c1) * p.ill.dose.pass.C2
p.ill.dose.fail <- p.c1 * p.ill.dose.fail.C1 + 
                  (1-p.c1) * p.ill.dose.fail.C2

fail.pass[k] <- p.ill.dose.fail/p.ill.dose.pass  #this ratio changes with conc.thresh

# compare these with EpiX intended ratio of ~2.1/0.38=5.5 (dose-response based on mix of exposure distributions)
passC1.C2[k] <- p.ill.dose.pass.C1/p.ill.dose.pass.C2
failC1.C2[k] <- p.ill.dose.fail.C1/p.ill.dose.fail.C2

p.ill.base[k] <- omega*p.ill.dose.pass + (1-omega)*p.ill.dose.fail

# calculate the new probability of illness per serving after diverting noncompliant lots
p.ill.new[k] <- omega*p.ill.dose.pass + (1-omega)*
            ((alpha.compfrac)*p.ill.base[k]+(1-alpha.compfrac)*p.ill.dose.fail)

# calculate newer probability of illness per serving if replace with passing lots
p.ill.newer[k] <- (omega+alpha.compfrac-omega*alpha.compfrac)*p.ill.dose.pass + 
                (1-omega)*(1-alpha.compfrac)*p.ill.dose.fail

# calculate illnesses avoided per year
ill.avoid[k] <- (1-(p.ill.new[k]/p.ill.base[k]))*num.ill

ill.avoid.lot[k] <- ill.avoid[k]/lots.fail

ill.avoid.newer[k] <- round((1-(p.ill.newer[k]/p.ill.base[k]))*num.ill)

perc.red[k] <- (1-(p.ill.new[k]/p.ill.base[k]))
perc.red.newer[k] <- (1-(p.ill.newer[k]/p.ill.base[k]))

print(cbind("done with concentration", conc.thresh[k]))
}

fail.pass
passC1.C2
failC1.C2
p.ill.base
p.ill.new
p.ill.newer
ill.avoid
ill.avoid.newer
ill.avoid.lot
perc.red
perc.red.newer


plot(log10(conc.thresh),ill.avoid.newer, 
     main="Carcass illnesses avoided at different concentration thresholds", ylim=c(0,round(max(ill.avoid.newer))),
     xlab="log10 concentration threshold (i.e., LOD)", 
     ylab="number of illnesses avoided", col="darkgreen")
points(log10(conc.thresh),ill.avoid, col="purple", pch=2)
legend("bottomleft",legend=c("replace with the baseline conc.", "replace with the passing conc."), col=c("purple","darkgreen"), pch=c(2,1) )


write.csv(data.frame(conc.thresh, ill.avoid, ill.avoid.newer,fail.pass,passC1.C2,
                     failC1.C2,p.ill.base,p.ill.new,p.ill.newer,ill.avoid.lot,
                     perc.red,perc.red.newer), file="carc_ouput_sim10mill_1_11_23.csv")




###########################################################################################
#  Serotype policy code
###########################################################################################

#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
#! CAUTION: ONLY INTENDED TO BE USED FOR PROD="CARC" AND CONC.THRESH=1/30 !#   
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

# Divert serocluster1 positives
# Define frequencies of Cluster1 by "schemes" (Scheme1 or 2)
# frequency of Cluster1 in Scheme1
p.c1s1 <- 0.88
# frequency of Cluster1 in Scheme2
p.c1s2 <- 0.09

# Define conditional probabilities of schemes given detection of Clusters 1 or 2
# probability of Scheme1 given detection of Cluster1
p.s1.c1 <- 0.62
# probability of Scheme1 given detection of Cluster2
p.s1.c2 <- 0.02

# share Cluster1 given fail, cluster1 detected
h <- p.s1.c1*p.c1s1+(1-p.s1.c1)*p.c1s2

# share Cluster1 given fail, cluster2 detected
k <- p.s1.c2*p.c1s1+ (1-p.s1.c2)*p.c1s2


p.ill.base.sero <- omega*p.ill.dose.pass + 
                  (1-omega)*p.c1*(h*p.ill.dose.fail.C1+(1-h)*p.ill.dose.fail.C2)+
                  (1-omega)*(1-p.c1)*(k*p.ill.dose.fail.C1+(1-k)*p.ill.dose.fail.C2)
p.ill.base.sero
p.ill.base  

p.ill.new.sero <- omega*p.ill.dose.pass +
  (1-omega)*p.c1*(alpha.compfrac)*p.ill.base.sero +
  (1-omega)*p.c1*(1-alpha.compfrac)*(h*p.ill.dose.fail.C1+(1-h)*p.ill.dose.fail.C2)+
  (1-omega)*(1-p.c1)*(k*p.ill.dose.fail.C1+(1-k)*p.ill.dose.fail.C2)
p.ill.new.sero  

ill.avoid.sero <- (1-(p.ill.new.sero/p.ill.base.sero))*num.ill
round(ill.avoid.sero)

(1-(p.ill.new.sero/p.ill.base.sero))  

(1-omega)*p.c1*(alpha.compfrac)*((h*p.ill.dose.fail.C1+(1-h)*p.ill.dose.fail.C2)-p.ill.base.sero)/p.ill.base.sero 


###########################################################################
#  Demonstrate effect of reducing frequency of C1
##########################################################################
# just reduce p.C1
p.c1.new <- seq(0,0.2,0.01)
p.ill.dose.new <- p.c1.new * p.ill.dose.C1 + (1-p.c1.new) * p.ill.dose.C2

ill.avoided.pc1 <- (1-(p.ill.dose.new/p.ill.dose))*chick.ill

red.pc1 <- (0.2-p.c1.new)/0.2

plot(red.pc1,ill.avoided.pc1,type="o",ylab="number of illnesses avoided",xlab="Reduction in fraction of C1 Salmonella")


# reduce freq of Scheme 1
# freq of Scheme1
p.c1 = 0.2
p.S1 <- seq(0,0.14,0.01)

# frequency of Cluster1 in Scheme1
p.c1s1 <- 0.88

# frequency of Cluster1 in Scheme2
p.c1s2 <- 0.09

# Define conditional probabilities of schemes given detection of Clusters 1 or 2
# probability of Scheme1 given detection of Cluster1
p.s1.c1.new <- p.c1s1*p.S1/(p.c1s2*(1-p.S1)+p.c1s1*p.S1)  #0.62
# probability of Scheme1 given detection of Cluster2
p.s1.c2.new <- (1-p.c1s1)*p.S1/((1-p.c1s2)*(1-p.S1)+(1-p.c1s1)*p.S1) #0.02

# share Cluster1 given fail, cluster1 detected
h.new <- p.s1.c1.new*p.c1s1+(1-p.s1.c1.new)*p.c1s2

# share Cluster1 given fail, cluster2 detected
k.new <- p.s1.c2.new*p.c1s1+ (1-p.s1.c2.new)*p.c1s2

p.c1.newer <- p.S1*p.c1s1 + (1-p.S1)*p.c1s2

p.ill.base.sero.new <- omega*p.ill.dose.pass + 
  (1-omega)*p.c1*(h.new*p.ill.dose.fail.C1+(1-h.new)*p.ill.dose.fail.C2)+
  (1-omega)*(1-p.c1)*(k.new*p.ill.dose.fail.C1+(1-k.new)*p.ill.dose.fail.C2)

ill.avoided.pS1 <- (1-p.ill.base.sero.new/p.ill.base.sero)*chick.ill

red.pS1 <- (0.14 - p.S1)/0.14

plot(red.pS1,ill.avoided.pS1,type="o",ylab="number of illnesses avoided",xlab="Reduction in fraction of units in Scheme 1")

plot(red.pc1,ill.avoided.pc1,type="o",pch=1,col="red",ylab="number of illnesses avoided",xlab="Reduction in fraction")
lines(red.pS1,ill.avoided.pS1,type="o",lty=2,pch=2,col="blue")
legend("topleft",legend=c("Fraction of C1 Salmonella", "Fraction of units in Scheme 1"), col=c("red","blue"), pch=c(1,2),cex=0.7 )

#########################################################################################
# THE FOLLOWING CODE ILLUSTRATES CALCULATIONS FOR APPROXIMATING THE FULL MODEL RESULTS.
# THE CODE IS COMMENTED OUT BECAUSE IT RELIES ON THE MODEL INPUTS ABOVE AND WOULD REQUIRE
# THAT THE EACH PRODUCT WAS SELECTED FOR THE APPROPRIATE mu.init and sig.init VALUES, AS 
# WELL AS THE APPROPRIATE ARRAY OF conc.thresh. ILLUSTRATIVE RESULTS ARE INCLUDED TO 
# GENERATE THE GRAPH IN THE REPORT.
#########################################################################################

# 
# # mean integer value of initial contaminantion distribution
# init_Mean <- exp(mu.init*log(10)+0.5*(sig.init*log(10))^2)
# init_Mean
# 
# # calculate conditional exp values of lognormal directly
# cndlE_pass <- (exp(mu.init*log(10)+0.5*(sig.init*log(10))^2)*
#                  pnorm((log(conc.thresh)-mu.init*log(10)-(sig.init*log(10))^2)/(sig.init*log(10))))/omega
# cndlE_pass
# 
# cndlE_fail <- (exp(mu.init*log(10)+0.5*(sig.init*log(10))^2)-cndlE_pass*omega)/(1-omega)
# cndlE_fail
# 
# # illustrate weighted ev's equal mean of lognormal
# omega*cndlE_pass+(1-omega)*cndlE_fail
# init_Mean
# 
# # calculate mean initial concentration after policy effect
# newMean <- omega*cndlE_pass + (1-omega)*(alpha.compfrac*init_Mean+
#                                            (1-alpha.compfrac)*cndlE_fail)
# newMean
# 
# # calculate effect of policy to compare with full Monte Carlo estimate
# # Note: this calc completely ignores attenuation effects!
# effect.init <- 1-(newMean/init_Mean)
# effect.init

# THE FOLLOWING ARRAYS WERE GENERATED FROM THE effect.init VARIABLE (above) FOR EACH PRODUCT
carc.effect.init <- c(0.03543439, 0.03799405, 0.04014084, 0.04185033, 0.04323456, 0.04412014,0.04438574, 0.04417657, 0.04385717, 0.04375015, 0.04361871, 0.04345456, 0.04324498, 0.04296920,
                      0.04259029, 0.04203422, 0.04112070, 0.03920880, 0.03686812, 0.03531306, 0.03317860, 0.03136293,
                      0.03001990, 0.02664490, 0.02204122, 0.01860496)

parts.effect.init <- c(0.0470187536, 0.0618489663, 0.0765387867, 0.0893636120, 0.0994739879, 0.1036062628, 0.1004519754, 0.0923313229, 0.0856834091, 0.0837724277, 0.0815598350, 0.0789641215, 0.0758678224,
                       0.0720930682, 0.0673520383, 0.0611329219, 0.0523817499, 0.0382545667, 0.0261576487, 0.0202910155,
                       0.0142401659, 0.0104575221, 0.0082743490, 0.0044664153, 0.0017604990, 0.0007959955) 

comm.effect.init <- c(0.1300448, 0.1440330, 0.1573861, 0.1698315, 0.1823835, 0.1941650, 0.2033074, 0.2100817, 0.2134445, 0.2142485, 0.2151141, 0.2160535,
                      0.2170835, 0.2182279, 0.2195226, 0.2210252, 0.2228382, 0.2251661, 0.2265962, 0.2270430, 0.2272109,
                      0.2270332, 0.2267388, 0.2254384, 0.2223454, 0.2188511)

# THE FOLLOWING ARRAYS WERE GENERATED FROM SIMULATING THE FULL MODEL'S perc.red VARIABLE FOR EACH PRODUCT
carc_sim <- c(0.035,0.037,0.039,0.039,0.04,0.039,
              0.037,0.035,0.032,0.033,0.032,0.03,0.029,0.029,0.028,0.027,0.024,0.021,
              0.016,0.013,0.011,0.011,0.009,0.004,0.006,0.005)

parts_sim <- c(0.046,0.06,0.073,0.083,0.087,0.086,
               0.076,0.063,0.055,0.054,0.053,0.047,0.045,0.04,0.036,0.03,0.025,0.013,
               0.009,0.007,0.004,0,0.001,0,0,0)

comm_sim <- c(0.13,0.144,0.157,
              0.169,0.18,0.19,0.197,0.2,0.2,0.201,0.201,0.2,0.2,0.199,0.198,0.196,0.193,
              0.185,0.174,0.165,0.156,0.147,0.14,0.121,0.099,0.081)


plot(log10(conc.thresh),comm.effect.init,col="blue",ylim=c(0,0.4),ylab="Proportional reduction in illnesses",xlab="Log10 concentration threshold")
points(log10(conc.thresh),comm_sim,pch=2,col="blue")
points(log10(conc.thresh),carc.effect.init, pch=1,col="black")
points(log10(conc.thresh),carc_sim,pch=2,col="black")
points(log10(conc.thresh),parts.effect.init, pch=1,col="red")
points(log10(conc.thresh),parts_sim,pch=2,col="red")
legend("topright",legend=c("Approximation", "Full simulation",
                           "Comminuted","Parts","Carcasses"), col=c("black","black","blue","red","black"), pch=c(1,2,22,22,22),cex=0.5 )


###############################################################################################
# THE FOLLOWING EXPLAINS CHANGES IN MODEL INPUTS TO CONDUCT THE SENSITIVITY ANALYSIS DESCRIBED
# IN THE REPORT.  ALL SENSITIVITY ANALYSES WERE COMPLETED FOR prod <- "comm".
###############################################################################################

# To examine the effect of changes to the attenuation distribution on the proportional reduction in 
# illnesses for a range of concentration thresholds, the model was simulated after modifying
# log.atten.mu <- X +ifelse(prod=="comm",0,log10(400/0.14)+log10(1/(454*4))), where X was entered
# as -9 or +2.  The output perc.red is saved for graphing purposes.


# To examine the effect of changes to the initial contamination distribution on the proportional reduction
# in illnesses for a range of concentration thresholds, the model was simulated after modifying separately
# the inputs mu.comm.g=-3.70 and sig.comm=1.949 by adding or subtracting 1 to each value. 
# The output perc.red is saved for graphing purposes.

# To examine the effect of changing the probability of Cluster 1 organisms on the proportional reduction
# in illnesses for a range of concentration thresholds, the model was simulated after modifying the input
# p.c1<- 0.2 to either 0 or 1. The output perc.red is saved for graphing purposes.  

# To examine the effect of changes to the C1 and C2 dose-response functions on the proportional reduction
# in illnesses for a range of concentration thresholds, the model was simulated after the following 
# modifications; 
# p.ill.dose.C1 <- integrate(f,-Inf, Inf, mu=log.dose.mu, sigma=log.dose.sig, cluster=1, est="X")$value 
# p.ill.dose.C2 <- integrate(f,-Inf, Inf, mu=log.dose.mu, sigma=log.dose.sig, cluster=2, est="X")$value
# where X=High or Low, and 
# p.ill.dose.pass.C1 <- as.numeric(colMeans(Response.dose.pass)[X])
# p.ill.dose.pass.C2 <- as.numeric(colMeans(Response.dose.pass)[Y])
# where X=3 and Y=6 for the upper bound dose-response functions and X=2 and Y=5 for the lower bound
# dose response functions. The output perc.red is saved for graphing purposes.


##########################################################################################################
# UNCERTAINTY ANALYSIS CODE
##########################################################################################################



# Human cases of salmonellosis partitioned by chicken products                          
iter = 1000000

FoodNet.cases =	7600  # per year
share.food =	0.66 #foodborne fraction (else is waterborne)
share.foreign =	0.11 # foreign travel associated illnesses 
FoodNet.coverage = 0.15 # FoodNet sites comprise 15% of U.S. population
UnderDx.mult =	rgamma(iter,32.83,1/0.74)  # 24.3 is avg number of true cases for each reported case (gamma(32.83 ,0.74))
Tot.salm.yr	=  FoodNet.cases*share.food*(1-share.foreign) * UnderDx.mult/FoodNet.coverage
summary(Tot.salm.yr)

chick.attrib =	rpert(iter,0.094,0.173,0.253)  #0.173 share of all illnesses attributed to chicken consumption (13 - 21 range)

carc.ill <- Tot.salm.yr*chick.attrib
summary(carc.ill)
round(mean(carc.ill),-3)
round(quantile(carc.ill,c(0.025,0.975)),-3)
parts.ill <- carc.ill*0.83
summary(parts.ill)
round(mean(parts.ill),-3)
round(quantile(parts.ill,c(0.025,0.975)),-3)
comm.ill <- carc.ill*0.06
summary(comm.ill)
round(mean(comm.ill),-3)
round(quantile(comm.ill,c(0.025,0.975)),-3)

# Read in the parameters of Pert distributions for the uncertain effectiveness of
# selected concentration thresholds.  The modes are the perc.red outputs from the baseline 
# model simulation.  The upper bounds are the perc.red outputs from the model approximation described
# above.  The lower bounds are the perc.red outputs from the model for the sensitivity analysis scenario
# where log.atten.mu <- 2.

pr<-read.csv(file="PertsPercRed_Aug_2023.csv")
pr

carc.03 <-rpert(iter,pr[1,2],pr[2,2],pr[3,2])*carc.ill
quantile(carc.03,c(0.025,0.975))
round(mean(carc.ill)*pr[2,2],-3)

carc.1 <-rpert(iter,pr[1,3],pr[2,3],pr[3,3])*carc.ill
round(quantile(carc.1,c(0.025,0.975)),-3)
round(mean(carc.ill)*pr[2,3],-3)

carc.10 <-rpert(iter,pr[1,4],pr[2,4],pr[3,4])*carc.ill
round(quantile(carc.10,c(0.025,0.975)),-3)
round(mean(carc.ill)*pr[2,4],-3)

carc.100 <-rpert(iter,pr[1,5],pr[2,5],pr[3,5])*carc.ill
round(quantile(carc.100,c(0.025,0.975)),-3)
round(mean(carc.ill)*pr[2,5],-3)

parts.03 <-rpert(iter,pr[4,2],pr[5,2],pr[6,2])*parts.ill
round(quantile(parts.03,c(0.025,0.975)),-3)
round(mean(parts.ill)*pr[5,2],-3)

parts.1 <-rpert(iter,pr[4,3],pr[5,3],pr[6,3])*parts.ill
round(quantile(parts.1,c(0.025,0.975)),-3)
round(mean(parts.ill)*pr[5,3],-3)

parts.10 <-rpert(iter,pr[4,4],pr[5,4],pr[6,4])*parts.ill
round(quantile(parts.10,c(0.025,0.975)),-3)
round(mean(parts.ill)*pr[5,4],-3)

parts.100 <-rpert(iter,pr[4,5],pr[5,5],pr[6,5])*parts.ill
round(quantile(parts.100,c(0.025,0.975)),-3)
round(mean(parts.ill)*pr[5,5],-3)

comm.03 <-rpert(iter,pr[7,2],pr[8,2],pr[9,2])*comm.ill
round(quantile(comm.03,c(0.025,0.975)),-3)
round(mean(carc.ill)*pr[8,2],-3)

comm.1 <-rpert(iter,pr[7,3],pr[8,3],pr[9,3])*comm.ill
round(quantile(comm.1,c(0.025,0.975)),-3)
round(mean(comm.ill)*pr[8,3],-3)

comm.10 <-rpert(iter,pr[7,4],pr[8,4],pr[9,4])*comm.ill
round(quantile(comm.10,c(0.025,0.975)),-3)
round(mean(comm.ill)*pr[8,4],-3)

comm.100 <-rpert(iter,pr[7,5],pr[8,5],pr[9,5])*comm.ill
round(quantile(comm.100,c(0.025,0.975)),-3)
round(mean(comm.ill)*pr[8,5],-3)


output <- c(mean(carc.ill)*pr[2,2],quantile(carc.03,c(0.025,0.975)),
            mean(carc.ill)*pr[2,3],quantile(carc.1,c(0.025,0.975)),
            mean(carc.ill)*pr[2,4],quantile(carc.10,c(0.025,0.975)),
            mean(carc.ill)*pr[2,5],quantile(carc.100,c(0.025,0.975)),
            mean(parts.ill)*pr[5,2],quantile(parts.03,c(0.025,0.975)),
            mean(parts.ill)*pr[5,3],quantile(parts.1,c(0.025,0.975)),
            mean(parts.ill)*pr[5,4],quantile(parts.10,c(0.025,0.975)),
            mean(parts.ill)*pr[5,5],quantile(parts.100,c(0.025,0.975)),
            mean(comm.ill)*pr[8,2],quantile(comm.03,c(0.025,0.975)),
            mean(comm.ill)*pr[8,3],quantile(comm.1,c(0.025,0.975)),
            mean(comm.ill)*pr[8,4],quantile(comm.10,c(0.025,0.975)),
            mean(comm.ill)*pr[8,5],quantile(comm.100,c(0.025,0.975)))

scen <- c("carc03Mode","carc03lo","carc03hi",
          "carc1Mode","carc1lo","carc1hi",
          "carc10Mode","carc10lo","carc10hi",
          "carc100Mode","carc100lo","carc100hi",
          "parts03Mode","parts03lo","parts03hi",
          "parts1Mode","parts1lo","parts1hi",
          "parts10Mode","parts10lo","parts10hi",
          "parts100Mode","parts100lo","parts100hi",
          "comm03Mode","comm03lo","comm03hi",
          "comm1Mode","comm1lo","comm1hi",
          "comm10Mode","comm10lo","comm10hi",
          "comm100Mode","comm100lo","comm100hi")

scen1<-c("carc03Mode","carc1Mode","carc10Mode","carc100Mode","parts03Mode","parts1Mode","parts10Mode",
         "parts100Mode","comm03Mode","comm1Mode","comm10Mode","comm100Mode")

output1 <- matrix(output,n=12,ncol=3,byrow=T)

write.csv(cbind(scen1,output1),"output.csv")


########################################################################################################
# "ILLUSTRATIVE DOSE" CALCULATIONS
########################################################################################################

# assume a given initial conc and determine doses for each product 
prod="carc"
# lognormal(log10) concentration parameters (represents between lot variability) 
mu.carc.ml=-4.51187
sig.carc=1.623983
mu.parts.ml=-3.017  
sig.parts=1.027     
mu.comm.g=-3.70 
sig.comm=1.949  

mu.init <- ifelse(prod=="carc",mu.carc.ml,ifelse(prod=="parts",mu.parts.ml,mu.comm.g)) 
sig.init <- ifelse(prod=="carc",sig.carc, ifelse(prod=="parts",sig.parts,sig.comm)) 

# attenuation distribution (adjusted for conversion from mL to g for carc and parts)
log.atten.mu <- -5+ifelse(prod=="comm",0,log10(400/0.14)+log10(1/(454*4)))
log.atten.sig <- 1.91

# specify concentration thresholds of interest
mu.init.ex <- c(1/325,1/30,1,10,100)


# what is exp val among failing lots?
omega <- pnorm(log10(mu.init.ex),mu.init,sig.init)
omega

ev.init <- exp(mu.init*log(10)+0.5*(log(10)*sig.init)^2)
ev.init

ev.pass <- (ev.init*pnorm((log(mu.init.ex)-mu.init*log(10)-(sig.init*log(10))^2)/(sig.init*log(10)),0,1))/omega
ev.pass

ev.fail <- (ev.init-omega*ev.pass)/(1-omega)
ev.fail

#what is exp val of dose if propagate ev.fail through attenuation?
ev.dose.fail <- exp(log(ev.fail)+log.atten.mu*log(10)+0.5*(log.atten.sig*log(10))^2)
ev.dose.fail


# integrate exp val of failing lots across DR
p.ill.dose.C1 <- rep(0,length(mu.init.ex))
p.ill.dose.C2 <- rep(0,length(mu.init.ex))
for (i in 1:length(mu.init.ex)) {
  
  p.ill.dose.C1[i] <- integrate(f,-Inf, Inf, mu=log10(ev.fail[i])+log.atten.mu, sigma=log.atten.sig, cluster=1, est="Mean")$value 
  p.ill.dose.C2[i] <- integrate(f,-Inf, Inf, mu=log10(ev.fail[i])+log.atten.mu, sigma=log.atten.sig, cluster=2, est="Mean")$value
  
}

# convert avg initial concentration from per mL to per g
ev.fail.g <- ev.fail*exp(log(400/0.14)+log(1/(454*4)))
if(prod=="comm"){ev.fail <- ev.fail} else {ev.fail<-ev.fail.g}
ev.fail

cbind(mu.init.ex,ev.fail,ev.dose.fail,p.ill.dose.C1,p.ill.dose.C2,1-omega)

#write.csv(data.frame(mu.init.ex,ev.fail,ev.dose.fail,p.ill.dose.C1,p.ill.dose.C2,dnorm(mu.init.ex,mu.init,sig.init)), file="pill.dose.1.27.23.csv")


